# -*- coding: utf-8 -*-
"""
Exceptions List: Follow this guide https://bit.ly/493plRK to creating a custom exception
Remember to test it!!!
"""


# TODO: We'll make this into a class and update it to just pass the print message only.
def exception_duplicate_url(exception, message):
    """
    This is a quick base exception to raise duplicate url in newsboat.
    """
    return exception(message)
